<p align="center">
<img src="logo.png" alt="Project Logo" style="width:100%; height:auto;" />
</p>

---

[![TreeSimulator](https://img.shields.io/badge/Powered%20by-TreeSimulator-green?style=flat-square)](https://github.com/evolbioinfo/treesimulator)
[![Remaster](https://img.shields.io/badge/Powered%20by-Remaster-blue?style=flat-square)](https://tgvaughan.github.io/remaster/)
[![AliSim](https://img.shields.io/badge/Powered%20by-AliSim-orange?style=flat-square)](https://iqtree.github.io/doc/AliSim)

**Phylogenie** is a Python package designed to easily simulate phylogenetic datasets—such as trees and multiple sequence alignments—with minimal setup effort.
